==> react-form-mobx-0.1.0.tgz: package/es/withFormStore.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import { polyfill } from 'react-lifecycles-compat';
import Context from './Context';

export default function withFormStore() {
	return function createFormStoreComponent(WrappedComponent) {
		var _class, _class2, _temp;

		var displayName = WrappedComponent.displayName,
		    name = WrappedComponent.name;

		var WithFormStore = polyfill(_class = (_temp = _class2 = function (_Component) {
			_inherits(WithFormStore, _Component);

			function WithFormStore() {
				_classCallCheck(this, WithFormStore);

				return _possibleConstructorReturn(this, (WithFormStore.__proto__ || Object.getPrototypeOf(WithFormStore)).apply(this, arguments));
			}

			_createClass(WithFormStore, [{
				key: 'render',
				value: function render() {
					var _this2 = this;

					return React.createElement(
						Context.Consumer,
						null,
						function (formStore) {
							return React.createElement(WrappedComponent, _extends({}, _this2.props, { formStore: formStore }));
						}
					);
				}
			}]);

			return WithFormStore;
		}(Component), _class2.displayName = 'WithFormStore(' + (displayName || name) + ')', _temp)) || _class;

		return WithFormStore;
	};
}

==> react-form-mobx-0.2.1.tgz: package/es/withFormStore.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import { polyfill } from 'react-lifecycles-compat';
import Context from './Context';

export default function withFormStore() {
	return function createFormStoreComponent(WrappedComponent) {
		var _class, _class2, _temp;

		var displayName = WrappedComponent.displayName,
		    name = WrappedComponent.name;

		var WithFormStore = polyfill(_class = (_temp = _class2 = function (_Component) {
			_inherits(WithFormStore, _Component);

			function WithFormStore() {
				_classCallCheck(this, WithFormStore);

				return _possibleConstructorReturn(this, (WithFormStore.__proto__ || Object.getPrototypeOf(WithFormStore)).apply(this, arguments));
			}

			_createClass(WithFormStore, [{
				key: 'getValue',
				value: function getValue() {
					return this.wrapped.inputStore.value;
				}
			}, {
				key: 'setValue',
				value: function setValue(value) {
					this.wrapped.inputStore.value = value;
				}
			}, {
				key: 'getPristineValue',
				value: function getPristineValue() {
					return this.wrapped.inputStore.pristineValue;
				}
			}, {
				key: 'setPristineValue',
				value: function setPristineValue(value) {
					this.wrapped.inputStore.pristineValue = value;
				}
			}, {
				key: 'getValidState',
				value: function getValidState() {
					return this.wrapped.inputStore.getValidState();
				}
			}, {
				key: 'render',
				value: function render() {
					var _this2 = this;

					return React.createElement(
						Context.Consumer,
						null,
						function (formStore) {
							return React.createElement(WrappedComponent, _extends({}, _this2.props, {
								formStore: formStore,
								ref: function ref(wrapped) {
									return _this2.wrapped = wrapped;
								}
							}));
						}
					);
				}
			}]);

			return WithFormStore;
		}(Component), _class2.displayName = 'WithFormStore(' + (displayName || name) + ')', _temp)) || _class;

		return WithFormStore;
	};
}
